==> dde-network-core_1.0.7.1.orig.tar.xz: dde-network-core-1.0.7.1/dock-network-plugin/translations/dock-network-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип безопасности</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Диапазон</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основной DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Получение IP адреса</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Подключено</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Проводная сеть %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Беспроводная сеть %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ошибка подключения</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dock-network-plugin/translations/dock-network-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступа</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип безопасности</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Диапазон</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска сети</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основной DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префикс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Получение IP адреса</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Подключено</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Отключено</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Получение адреса</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Проводная сеть %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Беспроводная сеть %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Устройство отключено</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, без доступа к Интернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ошибка подключения</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
</context>
</TS>
